<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableQueryFilterBar @on-reset="reset">
        <template #query>
          <QueryFilterItem tip-content="最近申报日期">
            <FieldDatePicker
              v-model="extraParamState.date"
              type="daterange"
              range-separator="~"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              clearable
              @change="getList()"
            ></FieldDatePicker>
          </QueryFilterItem>
          <QueryFilterItem tip-content="最近发放日期">
            <FieldDatePicker
              v-model="extraParamState.date"
              type="daterange"
              range-separator="~"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              clearable
              @change="getList()"
            ></FieldDatePicker>
          </QueryFilterItem>
          <QueryFilterItem>
            <FieldRadio
              v-model="extraParamState.showStatus"
              :value-enum="DataRangeEnumText"
              buttonStyle
              showAllBtn
              @change="getList()"
            />
          </QueryFilterItem>
          <QueryFilterItem>
            <SearchInput
              v-model="extraParamState.keyword"
              style="width: 200px"
              placeholder="批次号"
              @on-click-search="getList"
            >
            </SearchInput>
          </QueryFilterItem>
        </template>
      </ProTableQueryFilterBar>

      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
      </ProTableV2>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  LoadingLayout,
  AppContainer,
  useTable,
  ProTableQueryFilterBar,
  ProTableV2,
  defineOperationBtns,
  SearchInput,
  FieldRadio,
  QueryFilterItem,
  FieldDatePicker,
} from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
import { format } from '@/utils';
import { DataRangeEnum, DataRangeEnumText } from '@/constants';
import * as informationServices from '@/services/api/Information';
import _ from 'lodash';
import { ModelValueType } from 'element-plus';
import { useGlobalEventContext } from '@/hooks';

defineOptions({
  name: 'MaterialReview',
});

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'changeFlag',
    name: '申请批次号',
  },
  {
    id: '2',
    enCode: 'name',
    name: '申请园区',
  },
  {
    id: '3',
    enCode: 'idNumber',
    name: '园区类型',
  },
  {
    id: '4',
    enCode: 'workType',
    name: '申请奖励金月份',
  },
  {
    id: '5',
    enCode: 'gender',
    name: '奖励金汇总金额（元）',
  },
  {
    id: '6',
    enCode: 'age',
    name: '申报日期',
  },
  {
    id: '7',
    enCode: 'birthDay',
    name: '审核日期',
  },
  {
    id: '8',
    enCode: 'phoneNumber',
    name: '审核状态',
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'detailBtn',
      name: '详情',
    },
    emits: {
      onClick: (role) => goDetail(role),
    },
  },
  {
    data: {
      enCode: 'auditBtn',
      name: '审核',
    },
    emits: {
      onClick: (role) => goAudit(role),
    },
  },
]);

const router = useRouter();
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

const eventContext = useGlobalEventContext();

eventContext.addEvent('materialReviewAudit:audit', () => {
  getList(paginationState.pageIndex);
});

onMounted(async () => {
  await getList();
  state.loading = false;
});

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.GetInformationForManageInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        publishStartDate: format(extraParamState.date?.[0] ?? '', 'YYYY-MM-DD 00:00:00'),
        publishEndDate: format(extraParamState.date?.[1] ?? '', 'YYYY-MM-DD 23:59:59'),
      };
      let res = await informationServices.getInformationForManage(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keyword: '',
      showStatus: '' as any as DataRangeEnum,
      date: [] as unknown as ModelValueType,
      orderInput: [{ property: 'creationTime', order: OrderInputType.Desc }],
    },
  }
);

function goDetail(row: any) {
  router.push({
    name: 'MaterialReviewDetail',
    params: {
      id: row.id,
    },
  });
}
function goAudit(row: any) {
  router.push({
    name: 'MaterialReviewAudit',
    params: {
      id: row.id,
    },
  });
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
